==> comptechsoft-vue-foundation-1.0.7.tgz: package/src/~compvuetech/Components/Modals/Crud/Modal.js <==
import Modal from "../Base/Modal";
import Collection from "../../../Classes/Collection/Collection"
import AxiosCrud from "./../../../Classes/Axios/Crud/AxiosCrud"

class ModalCrud extends Modal {

    constructor(name) {
        super(name)

        /**
         * the blank record
         */
        this.blank = null

        /**
         * the blank record
         */
        this.old = null

        /**
         * the work record
         */
        this.record = null

        /**
         * controls collection
         */
        this.controls = new Collection()

        /**
         * crud axios object
         */
        this.axios = new AxiosCrud()

        /**
         * insert | update | delete
         */
        this.action = null

        /**
         * Layout Button Declansator 
         */
        this.actionButtons = {
            insert: {
                icon: 'la la-plus',
                caption: 'Add',
                htmlClass: 'btn btn-primary btn-sm',
            },
            update: {
                icon: 'la la-save',
                caption: 'Save',
                htmlClass: 'btn btn-primary btn-sm',
            },
            delete: {
                icon: 'la la-trash',
                caption: 'Delete',
                htmlClass: 'btn btn-danger btn-sm',
            },
        }


    }

    SetBlankRecord(record) {
        Vue.set(this, 'blank', {})
        Vue.set(this, 'record', {})
        _.each(record, (value, key) => {
            Vue.set(this.blank, key, value)
            Vue.set(this.record, key, value)
        })
        return this
    }

    SetEndpoint(value) {
        this.axios.SetEndpoint(value)
        return this
    }

    SetEndpoints(endpoints) {
        this.axios.SetEndpoints(endpoints)
        return this
    }


    AddControl(name, control) {
        this.controls.Put(name, control)
        return this
    }

    ResetRecord() {
        _.each(this.record, (value, key) => Vue.set(this.record, key, this.blank[key]))
    }

    get modalControls() {
        return this.controls.All()
    }

    get modalCaption() {
        return this.caption(this.action, this.old)
    }

    get modalActionsButton() {
        return ((! this.action) || (! this.actionButtons.hasOwnProperty(this.action))) ? null : this.actionButtons[this.action]
    }

    get endpoint() {
        return (! this.action ) ? null : this.axios.endpoints[this.action]
    }

    Show(action = null, old = null) {
        this.action = action
        Vue.set(this, 'old', {})
        if(old)
        {
            _.each(old, (value, field) => Vue.set(this.old, field, value))
            _.each(this.record, (value, field) => Vue.set(this.record, field, old[field]))
        }
        else
        {
            this.ResetRecord()
        }

        _.each(this.controls.All(), control => {
            Vue.set(control, 'enabled', ! (action == 'delete'))
        })

        this.axios.ResetResponse()

        super.Show()
    }

    Hide() {
        super.Hide()
        this.action = null
        return this
    }
} 

export default ModalCrud

==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Components/Modals/Crud/Modal.js <==
import Modal from "../Base/Modal";
import Collection from "../../../Classes/Collection/Collection"
import AxiosCrud from "./../../../Classes/Axios/Crud/AxiosCrud"

class ModalCrud extends Modal {

    constructor(name) {
        super(name)

        /**
         * the blank record
         */
        this.blank = null

        /**
         * the blank record
         */
        this.old = null

        /**
         * the work record
         */
        this.record = null

        /**
         * controls collection
         */
        this.controls = new _Classes_Collection_Collection__WEBPACK_IMPORTED_MODULE_1__["default"]()

        /**
         * crud axios object
         */
        this.axios = new _Classes_Axios_Crud_AxiosCrud__WEBPACK_IMPORTED_MODULE_2__["default"]()

        /**
         * insert | update | delete
         */
        this.action = null

        /**
         * Layout Button Declansator 
         */
        this.actionButtons = {
            insert: {
                icon: 'la la-plus',
                caption: 'Add',
                htmlClass: 'btn btn-primary btn-sm',
            },
            update: {
                icon: 'la la-save',
                caption: 'Save',
                htmlClass: 'btn btn-primary btn-sm',
            },
            delete: {
                icon: 'la la-trash',
                caption: 'Delete',
                htmlClass: 'btn btn-danger btn-sm',
            },
        }

        this.submit_tabindex = null

        this.first_tabindex = 1
    }

    SetBlankRecord(record) {
        Vue.set(this, 'blank', {})
        Vue.set(this, 'record', {})
        _.forOwn(record, (value, key) => {
            Vue.set(this.blank, key, value)
            Vue.set(this.record, key, value)
        })
        return this
    }

    SetEndpoint(value) {
        this.axios.SetEndpoint(value)
        return this
    }

    SetEndpoints(endpoints) {
        this.axios.SetEndpoints(endpoints)
        return this
    }

    AddControl(name, control) {
        this.controls.Put(name, control)
        return this
    }

    SetSubmitTabindex(value) {
        this.submit_tabindex = value
        return this
    }

    SetFirstTabindex(value) {
        this.first_tabindex = value
        return this
    }

    ResetRecord(vue = null) {
        _.forOwn(this.record, (value, key) => Vue.set(this.record, key, this.blank[key]))
    }

    get modalControls() {
        return this.controls.All()
    }

    get modalActionsButton() {
        return ((! this.action) || (! this.actionButtons.hasOwnProperty(this.action))) ? null : this.actionButtons[this.action]
    }

    get endpoint() {
        return (! this.action ) ? null : this.axios.endpoints[this.action]
    }

    Show(action = null, old = null) {
        this.action = action
        Vue.set(this, 'old', {})
        if(old)
        {
            _.forOwn(old, (value, field) => Vue.set(this.old, field, value))
            _.forOwn(this.record, (value, field) => Vue.set(this.record, field, old[field]))
        }
        else
        {
            this.ResetRecord()
        }

        _.forOwn(this.controls.All(), control => {
            Vue.set(control, 'enabled', ! (action == 'delete'))
        })

        this.axios.ResetResponse()

        super.Show()
    }

    Hide() {
        super.Hide()
        this.action = null
        return this
    }
} 

export default ModalCrud
